@@ -13,10 +13,12 @@ import datetime
 import time
 import os
 import json
+import sys
 
 import socket
+import sys
 
-DEBUG=1  # will change in MAIN  args
+# DEBUG=1  # will change in MAIN  args
 ACTUAL_CREDENTIALS={}
 
 
@@ -25,7 +27,7 @@ import warnings
 warnings.filterwarnings('ignore', message='Unverified HTTPS request')
 
 
-print("D...  project/module:  tdb_io/influx :", __version__ )
+# if DEBUG:print("D...  project/module:  tdb_io/influx :", __version__ )
 
 
 #OK
@@ -57,7 +59,7 @@ Checks if influx runs on IP AND shows databases
 r=client.query('SELECT "temp" FROM "autogen"."idx232"')
 
     """
-    print("D... checkd: ",IP,user)
+    if DEBUG:print("D... checkd: ",IP,user)
     ok = False
     autho = False
     dbs = []
@@ -78,12 +80,12 @@ r=client.query('SELECT "temp" FROM "autogen"."idx232"')
             autho = True
     if autho and user=="":
         print("I... trying with credentials from CONFIG")
-        creds,ips = read_infl_credentials()
+        creds,ips = read_infl_credentials( DEBUG = DEBUG)
 
         # NO SSL
         gotit = False
         try:
-            print("D... chkd:  getting client NO SSL")
+            if DEBUG:print("D... chkd:  getting client NO SSL")
             client = InfluxDBClient(IP, 8086,creds[0],creds[1],creds[2],ssl=False, timeout=3)
             client.get_list_database() # this checks error
             gotit = True
@@ -92,7 +94,7 @@ r=client.query('SELECT "temp" FROM "autogen"."idx232"')
 
         if not gotit:
             try:
-                print("D... chkd: getting client WITH SSL")
+                if DEBUG:print("D... chkd: getting client WITH SSL")
                 client = InfluxDBClient(IP, 8086,creds[0],creds[1],creds[2],ssl=True, timeout=3)
                 client.get_list_database() # this checks error
             except:
@@ -115,7 +117,7 @@ Checks if influx runs on IP, fir each DATABASE it shows ALL SERIES
 r=client.query('SELECT "temp" FROM "autogen"."idx232"')
 
     """
-    print("D... checks: ",IP,user)
+    if DEBUG:print("D... checks: ",IP,user)
 
     ok = False
     autho = False
@@ -138,7 +140,7 @@ r=client.query('SELECT "temp" FROM "autogen"."idx232"')
             autho = True
     if autho and user=="":
         print("I... trying with credentials from CONFIG")
-        creds,ips = read_infl_credentials()
+        creds,ips = read_infl_credentials( DEBUG=DEBUG)
 
         # NO SSL
         gotit = False
@@ -157,11 +159,11 @@ r=client.query('SELECT "temp" FROM "autogen"."idx232"')
             print("X... chks: exception without SSL")
 
         if not gotit:
-            print("D... chks: trying with SSL")
+            if DEBUG:print("D... chks: trying with SSL")
             client = InfluxDBClient(IP, 8086,creds[0],creds[1],creds[2],ssl=True, timeout=mytimeout)
             dbs = client.get_list_database() # generates excep
 
-        print("D... client obtained - nossl")
+        if DEBUG:print("D... client obtained - nossl")
         dbs = client.get_list_database()
     #print("D... list of databases obtained", dbs)
 
@@ -171,7 +173,7 @@ r=client.query('SELECT "temp" FROM "autogen"."idx232"')
     #TERMW-=1
     #-------------------------------- if series not given, list them
     if series == "":
-        print("D... stage check....")
+        if DEBUG:print("D... stage check....")
         for i in dbs:
             if i["name"].find("_")==0:
                 continue
@@ -202,18 +204,18 @@ r=client.query('SELECT "temp" FROM "autogen"."idx232"')
         return liseries
 
     #-----series given....we go to "read" option
-    print("D... stage read....")
+    if DEBUG:print("D... stage read....")
     dbs = [i['name'] for i in dbs]
     if not database in dbs:
-        print("X ... no such database", database,"in", dbs)
-        quit()
+        print("X ... no such database - exit", database,"in", dbs)
+        sys.exit(1)# quit()
     i = database
     print(i,"_"*(TERMW-len(i)-2) )
 
     sers = client.get_list_series( i )
     if not series in sers:
-        print("X ... no such series found", series)
-        quit()
+        print("X ... no such series found - exit", series)
+        sys.exit(1)# quit()
 
     client.switch_database(i)
     #
@@ -312,28 +314,28 @@ r=client.query('SELECT "temp" FROM "autogen"."idx232"')
             autho = True
     if autho and user=="":
         print("I... trying with credentials from CONFIG")
-        creds,ips = read_infl_credentials()
+        creds,ips = read_infl_credentials( DEBUG=DEBUG)
         # NO SSL
         client = InfluxDBClient(IP, 8086,creds[0],creds[1],creds[2],ssl=False, timeout=3)
-        print("D... client obtained - empty")
+        if DEBUG:print("D... client obtained - empty")
         dbs = client.get_list_database()
     dbs = [i['name'] for i in dbs]
-    print("D... list of databases obtained", dbs)
+    if DEBUG:print("D... list of databases obtained", dbs)
 
 
     TERMW = 55
     TERMW, rows = os.get_terminal_size(0)
 
     if not database in dbs:
-        print("X ... no such database", database,"in", dbs)
-        quit()
+        print("X ... no such database - exit", database,"in", dbs)
+        sys.exit(1)#quit()
     i = database
     print(i,"_"*(TERMW-len(i)-2) )
 
     sers = client.get_list_series( i )
     if not series in sers:
-        print("X ... no such series found", series)
-        quit()
+        print("X ... no such series found - exit", series)
+        sys.exit(1)# quit()
 
     client.switch_database(i)
     #
@@ -370,7 +372,7 @@ def checkout_hostname_database(database="test", series='idx0', IP="127.0.0.1", u
 
     MYHOSTNAME = socket.gethostname()
     NEWDB = "i_am_" + MYHOSTNAME
-    print("D... gethostname:", MYHOSTNAME, NEWDB )
+    if DEBUG:print("D... gethostname:", MYHOSTNAME, NEWDB )
 
     IP = "127.0.0.1"
     ok = False
@@ -393,7 +395,7 @@ def checkout_hostname_database(database="test", series='idx0', IP="127.0.0.1", u
             autho = True
     if autho and user=="":
         print("I... trying with credentials from CONFIG")
-        creds,ips = read_infl_credentials()
+        creds,ips = read_infl_credentials(DEBUG=DEBUG)
 
         # NO SSL
         gotit = False
@@ -401,16 +403,16 @@ def checkout_hostname_database(database="test", series='idx0', IP="127.0.0.1", u
             client = InfluxDBClient(IP, 8086,creds[0],creds[1],creds[2],ssl=False, timeout=3)
             dbs = client.get_list_database()
             gotit = True
-            print("D... client obtained with NO SSL")
+            if DEBUG:print("D... client obtained with NO SSL")
         except:
             print("X... NO SSL - didnt work, I try SSL")
 
         if not gotit:
             try:
-                print("D... client trying with  SSL")
+                if DEBUG:print("D... client trying with  SSL")
                 client = InfluxDBClient(IP, 8086,creds[0],creds[1],creds[2],ssl=True, timeout=3)
                 dbs = client.get_list_database()
-                print("D... client obtained with WITH SSL")
+                if DEBUG:print("D... client obtained with WITH SSL")
             except:
                 print("X... WITH SSL - didnt work", IP, 8086,creds[0],creds[1],creds[2])
 
@@ -418,7 +420,7 @@ def checkout_hostname_database(database="test", series='idx0', IP="127.0.0.1", u
         dbs = client.get_list_database()
     dbs = [i['name'] for i in dbs]
 
-    print("D... list of databases obtained", dbs)
+    if DEBUG:print("D... list of databases obtained", dbs)
 
     host_present = False
     ohost_present = False
@@ -434,7 +436,7 @@ def checkout_hostname_database(database="test", series='idx0', IP="127.0.0.1", u
         client.drop_database(ohost_name)
         #return
     if host_present:
-        print("D... all ok, my hostname is there with i_am_...")
+        if DEBUG:print("D... all ok, my hostname is there with i_am_...")
         return
     print("!... CREATE DATABASE myself:", NEWDB)
     client.create_database(NEWDB)
@@ -446,23 +448,23 @@ def checkout_hostname_database(database="test", series='idx0', IP="127.0.0.1", u
 
 
 
-def read_infl_credentials(config="~/.influx_userpassdb"):
+def read_infl_credentials(config="~/.influx_userpassdb", DEBUG=True):
     """ READ and RETURN Influxdb  Credentials
     """
     ips=[]
     ips1=[]
     ips2=[]
     try:
-        with open( os.path.expanduser("~/.myservice_discover8086") ) as f:
+        with open( os.path.expanduser("~/.seread_discover8086") ) as f:
             ips1=f.readlines()
     except:
-        print("X... NO FILE ~/.myservice_discover8086 with automatic IPs")
+        print("X... NO FILE ~/.seread_discover8086 with automatic IPs")
 
     try:
-        with open( os.path.expanduser("~/.myservice_permanent8086") ) as f:
+        with open( os.path.expanduser("~/.seread_permanent8086") ) as f:
             ips2=f.readlines()
     except:
-        print("X... NO FILE ~/.myservice_permanent8086 with permanent IPs")
+        print("X... NO FILE ~/.seread_permanent8086 with permanent IPs")
 
 
     ips=ips1+ips2
@@ -476,7 +478,7 @@ def read_infl_credentials(config="~/.influx_userpassdb"):
         print("X... no credentials in",config )
         sys.exit(1)
         return (["","","test"],ips)
-    print("D... exiting with",creds,ips)
+    if DEBUG:print("D... exiting with",creds,ips)
     return (creds,ips)
 
 
@@ -489,38 +491,40 @@ def read_infl_credentials(config="~/.influx_userpassdb"):
 def influxwrite( DATABASE="test", MEASUREMENT="test",
                  values="" ,
                  #IP="127.0.0.1",
-                 initialconfig="2DOlater" ):
+                 initialconfig="2DOlater" , DEBUG = False):
     """write data to influx. DATABASE=test,MEASUREMENT=hostname; ./influx.py influxwrite -values b=1
     """
-    print("D... ************************ writin to influx ******************************")
-    creds,ips=read_infl_credentials()
-    print( creds ,"##", ips )
+    if DEBUG:print("D... ************************ writin to influx ******************************")
+    creds,ips=read_infl_credentials( DEBUG=DEBUG)
+    # print( creds ,"##", ips )
     for IP in ips:
+        if DEBUG:print("D... IP=",IP)
         if len(IP)<7:
-            print("D... IP too short......... quit")
-            quit()
+            print("X... IP too short......... skip")
+            continue
         if IP[0].isdigit(): #
-            print("D... IP is number......... no ssl used")
+            print("i... IP is number......... no ssl used")
             client = InfluxDBClient(IP, 8086,creds[0],creds[1],creds[2],ssl=False, timeout=3)
         else:
-            print("D... IP is text. ...........I do ssl ")
+            if DEBUG:print("D... IP is text. ...........I do ssl ")
             client = InfluxDBClient(IP, 8086,creds[0],creds[1],creds[2],ssl=True, verify_ssl=False,timeout=8)
 
         MYHOSTNAME=socket.gethostname()
-        print("D....................MYHOST=",MYHOSTNAME )
+        if DEBUG:print("D....................MYHOST=",MYHOSTNAME )
 
 
-        print("D....................INFLUX WRITING= DB/MEASUREMENT",DATABASE,MEASUREMENT )
+        if DEBUG:print("D....................INFLUX WRITING= DB/MEASUREMENT",DATABASE,MEASUREMENT )
 
         if len(values)==0:
-            print("D....  no values given ... do you need to look at current values? ")
+            if DEBUG:print("D....  no values given ... do you need to look at current values? -exit")
             #mongo2h5( DATABASE, COLLECTION, nlimit=100000, write_h5=False)
-            quit()
+            #quit()
+            sys.exit(1)
         insertvals=values.split(",")
-        print("D... insert pairs:", insertvals)
+        if DEBUG:print("D... insert pairs:", insertvals)
         INSERTDICT={}
         for i in insertvals:
-            print("D... insert pair:",i)
+            if DEBUG:print("D... insert pair:",i)
             key=i.split("=")[0]
             val=float(i.split("=")[1])
             INSERTDICT[key]=val
@@ -530,9 +534,12 @@ def influxwrite( DATABASE="test", MEASUREMENT="test",
         json_body = [ {"measurement":MYHOSTNAME+"_"+MEASUREMENT} ]
         #json_body[0]["fields"]={}
         json_body[0]["fields"]=INSERTDICT
-        print("D... ",json_body)
-        client.write_points(json_body)
-        print("D... ************************ influx DONE ******************************")
+        if DEBUG:print("D... ",json_body)
+        res = client.write_points(json_body)
+        #print("writepoints response=",res)
+        if DEBUG:print("D... ************************ influx DONE ******************************")
+        return res # client write response
+
 
 
 
@@ -545,8 +552,11 @@ def influxwrite( DATABASE="test", MEASUREMENT="test",
 #=============================================================
 #=============================================================
 if __name__=="__main__":
-    print("D...","_"*40)
 
+
+    print("F... you can run ")
+    print('  ./influx.py influxwrite test testmes "a=1" --DEBUG  ')
+    print()
     Fire( {
       'influxwrite':influxwrite ,
       'check_port':check_port ,
